@@ -32,7 +32,9 @@ class TQWidget;
 class TQDragObject;
 class PlaylistItem;
 class MRL;
-class TDEIO::Job;
+namespace TDEIO {
+    class Job;
+}
 
 class UrlListView : public TDEListView
 {
