@@ -474,7 +474,7 @@ void Disc::startCD( const TQString &device, bool rip )
 			}
 		}
 		else {
-			cddb->set_server( "freedb.freedb.org", 8880 );
+			cddb->set_server( "gnudb.gnudb.org", 8880 );
 			if ( cddb->queryCD(qvl) ) {
 				artistLab->setText( cddb->artist() );
 				albumLab->setText( cddb->title() );
@@ -540,7 +540,7 @@ void Disc::startDVD( const TQString &device )
 			i=0;
 			while ( i<(int)dcopList.count() ) {
 				//kdDebug() << dcopList[i+5] << " * " << dcopList[i+6] << " * " << dcopList[i+10] << endl;
-				if ( dcopList[i+10]=="media/dvdvideo" ) {
+				if ( dcopList[i+10]=="media/dvdvideo" || dcopList[i+10]=="media/blurayvideo") {
 					devList.append( dcopList[i+5] );
 				}
 				else if ( dcopList[i+10]=="media/cdrom_mounted"
