@@ -29,10 +29,10 @@
 #include <tqregexp.h>
 #include <tqradiobutton.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
+#include <tdemessagebox.h>
+#include <tdefiledialog.h>
 #include <ktar.h>
 #include <kstandarddirs.h>
 
@@ -151,7 +151,7 @@ DVBconfig::DVBconfig( const TQString &dvbConf )
 	dir.setPath( dvbConfigIconsDir );
 	if ( !dir.exists() )
 		dir.mkdir( dvbConfigIconsDir );
-	config = new KConfig( dvbConfigDir+"dvbrc" );
+	config = new TDEConfig( dvbConfigDir+"dvbrc" );
 	downProgress = 0;
 	sizeFile = 0;
 	categories.setAutoDelete( true );
@@ -286,11 +286,11 @@ bool DVBconfig::loadDvbData( TQWidget *parent )
 	downProgress->progressBar()->setTotalSteps( 100 );
 	//job = file_copy( KURL( "http://hftom.free.fr/kaxtv/dvbdata.tar.gz" ), KURL( dvbConfigDir+"dvbdata.tar.gz" ), -1, true, false, false );
 	job = file_copy( KURL( "http://hftom.free.fr/kaxtv/dvbdata.tar.gz" ), KURL( dvbConfigDir+"dvbdata.tar.gz" ), -1, true, false, false );
-	connect( job, TQT_SIGNAL(result(KIO::Job*)), this, TQT_SLOT(setDownloadResult(KIO::Job*)) );
-	connect( job, TQT_SIGNAL(percent(KIO::Job*,unsigned long)), this, TQT_SLOT(setDownloadPercent(KIO::Job*,unsigned long)) );
+	connect( job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(setDownloadResult(TDEIO::Job*)) );
+	connect( job, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(setDownloadPercent(TDEIO::Job*,unsigned long)) );
 	downProgress->exec();
-	disconnect( job, TQT_SIGNAL(result(KIO::Job*)), this, TQT_SLOT(setDownloadResult(KIO::Job*)) );
-	disconnect( job, TQT_SIGNAL(percent(KIO::Job*,unsigned long)), this, TQT_SLOT(setDownloadPercent(KIO::Job*,unsigned long)) );
+	disconnect( job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(setDownloadResult(TDEIO::Job*)) );
+	disconnect( job, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(setDownloadPercent(TDEIO::Job*,unsigned long)) );
 	if ( downProgress ) {
 		delete downProgress;
 		downProgress = 0;
@@ -569,7 +569,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	KDialogBase ( IconList, i18n("DVB Settings"), Ok|Cancel, Ok, parent, "dvbConfigDialog", true, true )
 {
 	TQLabel *lab;
-	KIconLoader *icon = new KIconLoader();
+	TDEIconLoader *icon = new TDEIconLoader();
 	TQHBoxLayout *h1;
 	TQString s;
 	int i;
@@ -590,7 +590,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 
 	for ( i=0; i<(int)dvbConfig->devList.count(); i++ ) {
 		page = addPage( i18n("DVB Device")+" "+TQString("%1:%2").arg(dvbConfig->devList.at(i)->adapter).arg(dvbConfig->devList.at(i)->tuner), i18n("Device Settings"),
-			KGlobal::instance()->iconLoader()->loadIcon( "hwinfo", KIcon::NoGroup, KIcon::SizeMedium ) );
+			TDEGlobal::instance()->iconLoader()->loadIcon( "hwinfo", TDEIcon::NoGroup, TDEIcon::SizeMedium ) );
 		vb = new TQVBoxLayout( page, 6, 6 );
 		gb = new TQGroupBox( "", page );
 		grid = new TQGridLayout( gb, 1, 1, 20, 6 );
@@ -652,7 +652,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			connect( satNumber[i], TQT_SIGNAL(signalValueChanged(int,int)), this, TQT_SLOT(satNumberChanged(int,int)));
 			grid->addWidget( satNumber[i], gridLine, 1 );
 			usals = new KPushButton( gb );
-			usals->setGuiItem( KGuiItem(i18n("Set rotor coordinates..."), icon->loadIconSet("move", KIcon::Small) ) );
+			usals->setGuiItem( KGuiItem(i18n("Set rotor coordinates..."), icon->loadIconSet("move", TDEIcon::Small) ) );
 			connect( usals, TQT_SIGNAL(clicked()), this, TQT_SLOT(setUsals()));
 			grid->addWidget( usals, gridLine, 2 );
 
@@ -669,7 +669,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			++gridLine;
 
 			lnb0[i] = new MPushButton( gb, i, 0 );
-			lnb0[i]->setGuiItem( KGuiItem(i18n("LNB 1 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb0[i]->setGuiItem( KGuiItem(i18n("LNB 1 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb0[i]->setEnabled(true);
 			grid->addWidget( lnb0[i], gridLine, 0 );
 			connect( lnb0[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
@@ -698,7 +698,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			++gridLine;
 
 			lnb1[i] = new MPushButton( gb, i, 1 );
-			lnb1[i]->setGuiItem( KGuiItem(i18n("LNB 2 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb1[i]->setGuiItem( KGuiItem(i18n("LNB 2 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb1[i]->setEnabled(false);
 			grid->addWidget( lnb1[i], gridLine, 0 );
 			connect( lnb1[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
@@ -730,7 +730,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			++gridLine;
 
 			lnb2[i] = new MPushButton( gb, i, 2 );
-			lnb2[i]->setGuiItem( KGuiItem(i18n("LNB 3 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb2[i]->setGuiItem( KGuiItem(i18n("LNB 3 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb2[i]->setEnabled(false);
 			grid->addWidget( lnb2[i], gridLine, 0 );
 			connect( lnb2[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
@@ -762,7 +762,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			++gridLine;
 
 			lnb3[i] = new MPushButton( gb, i, 3 );
-			lnb3[i]->setGuiItem( KGuiItem(i18n("LNB 4 settings..."), icon->loadIconSet("hwinfo", KIcon::Small) ) );
+			lnb3[i]->setGuiItem( KGuiItem(i18n("LNB 4 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb3[i]->setEnabled(false);
 			grid->addWidget( lnb3[i], gridLine, 0 );
 			connect( lnb3[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
@@ -827,7 +827,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	}
 
 	page = addPage(i18n("Recording"),i18n("DVB Recording Options"),
-		KGlobal::instance()->iconLoader()->loadIcon( "hdd_unmount", KIcon::NoGroup, KIcon::SizeMedium ) );
+		TDEGlobal::instance()->iconLoader()->loadIcon( "drive-harddisk", TDEIcon::NoGroup, TDEIcon::SizeMedium ) );
 	vb = new TQVBoxLayout( page, 6, 6 );
 	gb = new TQGroupBox( "", page );
 	grid = new TQGridLayout( gb, 1, 1, 20, 6 );
@@ -838,7 +838,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	recordDirLe->setReadOnly( true );
 	grid->addWidget( recordDirLe, 0, 1 );
 	recordDirBtn = new TQToolButton( gb );
-	recordDirBtn->setIconSet( icon->loadIconSet("fileopen", KIcon::Small) );
+	recordDirBtn->setIconSet( icon->loadIconSet("document-open", TDEIcon::Small) );
 	grid->addWidget( recordDirBtn, 0, 2 );
 
 	lab = new TQLabel( i18n("Time shifting directory:"), gb );
@@ -847,7 +847,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	shiftDirLe->setReadOnly( true );
 	grid->addWidget( shiftDirLe, 1, 1 );
 	shiftDirBtn = new TQToolButton( gb );
-	shiftDirBtn->setIconSet( icon->loadIconSet("fileopen", KIcon::Small) );
+	shiftDirBtn->setIconSet( icon->loadIconSet("document-open", TDEIcon::Small) );
 	grid->addWidget( shiftDirBtn, 1, 2 );
 
 	lab = new TQLabel( i18n("Begin margin:"), gb );
@@ -892,7 +892,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	filenameFormatLe = new TQLineEdit( gb );
 	grid->addWidget( filenameFormatLe, 7, 1 );
 	helpNameBtn = new TQToolButton( gb );
-	helpNameBtn->setIconSet( icon->loadIconSet("help", KIcon::Small) );
+	helpNameBtn->setIconSet( icon->loadIconSet("help", TDEIcon::Small) );
 	grid->addWidget( helpNameBtn, 7, 2 );
 
 	vb->addWidget( gb );
@@ -907,7 +907,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	filenameFormatLe->setText( dvbConfig->filenameFormat );
 
 	page = addPage(i18n("Broadcasting"),i18n("DVB Broadcasting"),
-		KGlobal::instance()->iconLoader()->loadIcon( "network_local", KIcon::NoGroup, KIcon::SizeMedium ) );
+		TDEGlobal::instance()->iconLoader()->loadIcon( "network_local", TDEIcon::NoGroup, TDEIcon::SizeMedium ) );
 	vb = new TQVBoxLayout( page, 6, 6 );
 	gb = new TQGroupBox( "", page );
 	grid = new TQGridLayout( gb, 1, 1, 20, 6 );
@@ -933,7 +933,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	sportSpin->setValue( dvbConfig->senderPort );
 
 	page = addPage(i18n("Misc"),i18n("Misc"),
-		KGlobal::instance()->iconLoader()->loadIcon( "misc", KIcon::NoGroup, KIcon::SizeMedium ) );
+		TDEGlobal::instance()->iconLoader()->loadIcon( "misc", TDEIcon::NoGroup, TDEIcon::SizeMedium ) );
 	vb = new TQVBoxLayout( page, 6, 6 );
 	gb = new TQGroupBox( "", page );
 	grid = new TQGridLayout( gb, 1, 1, 20, 6 );
@@ -962,13 +962,13 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	lab = new TQLabel( i18n("Update scan data:"), gb );
 	grid->addWidget( lab, 3, 0 );
 	updateBtn = new KPushButton( gb );
-	updateBtn->setGuiItem( KGuiItem(i18n("Download"), icon->loadIconSet("khtml_kget", KIcon::Small) ) );
+	updateBtn->setGuiItem( KGuiItem(i18n("Download"), icon->loadIconSet("tdehtml_kget", TDEIcon::Small) ) );
 	grid->addWidget( updateBtn, 3, 1 );
 
 	lab = new TQLabel( i18n("Dump epg's events to \n~/kaffeine_dvb_events.tx:"), gb );
 	grid->addWidget( lab, 4, 0 );
 	dumpBtn = new KPushButton( gb );
-	dumpBtn->setGuiItem( KGuiItem(i18n("Dump"), icon->loadIconSet("filesave", KIcon::Small) ) );
+	dumpBtn->setGuiItem( KGuiItem(i18n("Dump"), icon->loadIconSet("document-save", TDEIcon::Small) ) );
 	grid->addWidget( dumpBtn, 4, 1 );
 
 	vb->addWidget( gb );
@@ -976,7 +976,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 
 	if ( p ) {
 		page = addPage(i18n("DVB plugins"),i18n("DVB plugins"),
-			KGlobal::instance()->iconLoader()->loadIcon( "misc", KIcon::NoGroup, KIcon::SizeMedium ) );
+			TDEGlobal::instance()->iconLoader()->loadIcon( "misc", TDEIcon::NoGroup, TDEIcon::SizeMedium ) );
 		vb = new TQVBoxLayout( page, 6, 6 );
 		gb = new TQGroupBox( "", page );
 		grid = new TQGridLayout( gb, 1, 1, 20, 6 );
